Harta rutelor booklabd - BookLab
Author: Petre Iordanescu (petre.iordanescu@gmail.com)

Skip to content

# Booklab server routes

Here you can find all active and available routes exposed by Booklab server (`booklabd`) component.

    Endpoint     Methods  Rule
    -----------  -------  ---------------------
    about        GET      /api/about/
    api_bbld     GET      /api/bbld/
    api_bcat     GET      /api/bcat/
    api_bstatus  GET      /api/bstatus/
    api_dplb     GET      /api/dplb/
    api_edtb     GET      /api/edtb/
    api_newb     GET      /api/newb/
    api_orgm     GET      /api/orgm/
    api_prvb     GET      /api/prvb/
    index        GET      /
    static       GET      /docs/<path:filename>
    version      GET      /api/version/

Last update: December 7, 2025